@@ -1,7 +1,7 @@
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2010  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
  *
  * This file is part of lingot.
  *
@@ -23,11 +23,12 @@
 #ifndef __LINGOT_AUDIO_ALSA_H__
 #define __LINGOT_AUDIO_ALSA_H__
 
-#include "lingot-core.h"
 #include "lingot-audio.h"
 
-LingotAudio* lingot_audio_alsa_new(LingotCore*);
-void lingot_audio_alsa_destroy(LingotAudio*);
-int lingot_audio_alsa_read(LingotAudio*, LingotCore*);
+LingotAudioHandler* lingot_audio_alsa_new(char* device, int sample_rate);
+void lingot_audio_alsa_destroy(LingotAudioHandler*);
+int lingot_audio_alsa_read(LingotAudioHandler*);
+LingotAudioSystemProperties* lingot_audio_alsa_get_audio_system_properties(
+		audio_system_t);
 
 #endif
