@@ -1,8 +1,7 @@
-//-*- C++ -*-
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2010  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
  *
  * This file is part of lingot.
  *
@@ -27,8 +26,13 @@
 #include <math.h>
 #include <locale.h>
 
+#include "lingot-defs.h"
 #include "lingot-config.h"
-#include "lingot-mainframe.h"
+#include "lingot-config-scale.h"
+#include "lingot-msg.h"
+#include "lingot-i18n.h"
+
+#define MAX(a, b) (((a) > (b)) ? (a) : (b))
 
 #define N_OPTIONS 20
 
@@ -70,21 +74,32 @@ LingotConfig* lingot_config_new() {
 
 	LingotConfig* config = malloc(sizeof(LingotConfig));
 
-	lingot_config_reset(config); // set default values.
-
+	config->max_nr_iter = 10; // iterations
+	config->window_type = HAMMING;
+	config->scale = lingot_config_scale_new();
 	return config;
 }
 
 void lingot_config_destroy(LingotConfig* config) {
+	lingot_config_scale_destroy(config->scale);
+	free(config->scale);
 	free(config);
 }
 
+void lingot_config_copy(LingotConfig* dst, LingotConfig* src) {
+	LingotScale* dst_scale = dst->scale;
+	*dst = *src;
+	dst->scale = dst_scale;
+	lingot_config_scale_copy(dst->scale, src->scale);
+}
+
 //----------------------------------------------------------------------------
-void lingot_config_reset(LingotConfig* config) {
+
+void lingot_config_restore_default_values(LingotConfig* config) {
 
 	config->audio_system = AUDIO_SYSTEM_ALSA;
-	sprintf(config->audio_dev, "%s", "/dev/dsp");
-	sprintf(config->audio_dev_alsa, "%s", "plughw:0");
+	sprintf(config->audio_dev[AUDIO_SYSTEM_OSS], "%s", "/dev/dsp");
+	sprintf(config->audio_dev[AUDIO_SYSTEM_ALSA], "%s", "plughw:0");
 
 	config->sample_rate = 44100; // Hz
 	config->oversampling = 25;
@@ -104,49 +119,48 @@ void lingot_config_reset(LingotConfig* config) {
 	config->dft_number = 2; // DFTs
 	config->dft_size = 15; // samples
 
-	config->max_nr_iter = 10; // iterations
-
 	//--------------------------------------------------------------------------
 
-	config->vr = -0.45; // near to minimum
-
+	lingot_config_scale_restore_default_values(config->scale);
 	lingot_config_update_internal_params(config);
 }
 
 //----------------------------------------------------------------------------
 
-int lingot_config_update_internal_params(LingotConfig* config) {
-	int result = 1;
+void lingot_config_update_internal_params(LingotConfig* config) {
 
 	// derived parameters.
-	config->root_frequency = 440.0 * pow(2.0, config->root_frequency_error
-			/ 1200.0);
 	config->temporal_buffer_size = (unsigned int) ceil(config->temporal_window
 			* config->sample_rate / config->oversampling);
-	config->read_buffer_size = (unsigned int) ceil(config->sample_rate
-			/ config->calculation_rate);
-	config->read_buffer_size = 1024;
 	config->peak_rejection_relation_nu = pow(10.0,
 			config->peak_rejection_relation_db / 10.0);
 	config->noise_threshold_nu = pow(10.0, config->noise_threshold_db / 10.0);
 	config->gain_nu = pow(10.0, config->gain / 20.0);
 
-	if (config->temporal_buffer_size < config->fft_size) {
-		config->temporal_window = ((double) config->fft_size
-				* config->oversampling) / config->sample_rate;
-		config->temporal_buffer_size = config->fft_size;
-		result = 0;
+	LingotScale* scale = config->scale;
+	if (scale->notes == 1) {
+		scale->max_offset_rounded = 1200.0;
+	} else {
+		int i;
+		FLT max_offset = 0.0;
+		for (i = 1; i < scale->notes; i++) {
+			max_offset = MAX(max_offset, scale->offset_cents[i]
+					- scale->offset_cents[i - 1]);
+		}
+		scale->max_offset_rounded = max_offset;
 	}
 
-	return result;
+	config->gauge_rest_value = -0.45 * scale->max_offset_rounded;
+	sprintf(config->audio_dev[AUDIO_SYSTEM_JACK], "%s", "");
 }
 
 //----------------------------------------------------------------------------
 
 // internal parameters mapped to each token in the config file.
 void lingot_map_parameters(LingotConfig* config, void* params[]) {
-	void* c_params[] = { &config->audio_system, &config->audio_dev,
-			&config->audio_dev_alsa, &config->sample_rate,
+	void* c_params[] = { &config->audio_system,
+			&config->audio_dev[AUDIO_SYSTEM_OSS],
+			&config->audio_dev[AUDIO_SYSTEM_ALSA], &config->sample_rate,
 			&config->oversampling, &config->root_frequency_error,
 			&config->min_frequency, &config->fft_size,
 			&config->temporal_window, &config->noise_threshold_db,
@@ -165,6 +179,7 @@ void lingot_config_save(LingotConfig* config, char* filename) {
 	void* params[N_OPTIONS]; // parameter pointer array.
 	void* param = NULL;
 	char* option = NULL;
+	char buff[80];
 
 	lingot_map_parameters(config, params);
 
@@ -207,6 +222,22 @@ void lingot_config_save(LingotConfig* config, char* filename) {
 		}
 	}
 
+	fprintf(fp, "\n");
+	fprintf(fp, "SCALE = {\n");
+	fprintf(fp, "NAME = %s\n", config->scale->name);
+	fprintf(fp, "BASE_FREQUENCY = %f\n", config->scale->base_frequency);
+	fprintf(fp, "NOTE_COUNT = %d\n", config->scale->notes);
+	fprintf(fp, "NOTES = {\n");
+
+	for (i = 0; i < config->scale->notes; i++) {
+		lingot_config_scale_format_shift(buff, config->scale->offset_cents[i],
+				config->scale->offset_ratios[0][i],
+				config->scale->offset_ratios[1][i]);
+		fprintf(fp, "%s\t%s\n", config->scale->note_name[i], buff);
+	}
+
+	fprintf(fp, "}\n"), fprintf(fp, "}\n"),
+
 	fclose(fp);
 
 	if (lc_all) {
@@ -225,9 +256,17 @@ void lingot_config_load(LingotConfig* config, char* filename) {
 	int deprecated_option = 0;
 	char* char_buffer_pointer;
 	const static char* delim = " \t=\n";
+	const static char* delim2 = " \t\n";
 	void* params[N_OPTIONS]; // parameter pointer array.
 	void* param = NULL;
 	char* option = NULL;
+	int reading_scale = 0;
+	char* nl;
+	int parse_errors = 0;
+	int command_count = 0;
+
+	// restore default values for non specified parameters
+	lingot_config_restore_default_values(config);
 
 	lingot_map_parameters(config, params);
 
@@ -252,8 +291,6 @@ void lingot_config_load(LingotConfig* config, char* filename) {
 		if (!fgets(char_buffer, MAX_LINE_SIZE, fp))
 			break;;
 
-		//    printf("line %d: %s\n", line, s1);
-
 		if (char_buffer[0] == '#')
 			continue;
 
@@ -263,6 +300,78 @@ void lingot_config_load(LingotConfig* config, char* filename) {
 		if (!char_buffer_pointer)
 			continue; // blank line.
 
+
+		if (!strcmp(char_buffer_pointer, "SCALE")) {
+			reading_scale = 1;
+			config->scale = lingot_config_scale_new();
+			command_count++;
+			continue;
+		}
+
+		if (reading_scale) {
+
+			if (!strcmp(char_buffer_pointer, "NAME")) {
+				char_buffer_pointer += 4;
+				while (1) {
+					nl = strchr(delim, *char_buffer_pointer);
+					if (!nl)
+						break;
+					char_buffer_pointer++;
+				}
+				nl = strrchr(char_buffer_pointer, '\r');
+				if (nl)
+					*nl = '\0';
+				nl = strrchr(char_buffer_pointer, '\n');
+				if (nl)
+					*nl = '\0';
+				config->scale->name = strdup(char_buffer_pointer);
+				continue;
+			}
+			if (!strcmp(char_buffer_pointer, "BASE_FREQUENCY")) {
+				char_buffer_pointer = strtok(NULL, delim);
+				sscanf(char_buffer_pointer, "%lg",
+						&config->scale->base_frequency);
+				continue;
+			}
+			if (!strcmp(char_buffer_pointer, "NOTE_COUNT")) {
+				char_buffer_pointer = strtok(NULL, delim);
+				sscanf(char_buffer_pointer, "%hu", &config->scale->notes);
+				lingot_config_scale_allocate(config->scale,
+						config->scale->notes);
+				continue;
+			}
+
+			if (!strcmp(char_buffer_pointer, "NOTES")) {
+				int i = 0;
+				for (i = 0; i < config->scale->notes; i++) {
+					line++;
+					if (!fgets(char_buffer, MAX_LINE_SIZE, fp))
+						break;
+					// tokens into the line.
+					char_buffer_pointer = strtok(char_buffer, delim2);
+					config->scale->note_name[i] = strdup(char_buffer_pointer);
+					char_buffer_pointer = strtok(NULL, delim2);
+					if (!lingot_config_scale_parse_shift(char_buffer_pointer,
+							&config->scale->offset_cents[i],
+							&config->scale->offset_ratios[0][i],
+							&config->scale->offset_ratios[1][i])) {
+						parse_errors = 1;
+					}
+				}
+				line++;
+				if (!fgets(char_buffer, MAX_LINE_SIZE, fp))
+					break; // }
+
+				continue;
+			}
+
+			if (!strcmp(char_buffer_pointer, "}")) {
+				reading_scale = 0;
+				continue;
+			}
+
+		}
+
 		deprecated_option = 0;
 		for (option_index = 0; options[option_index]; option_index++) {
 			if (!strcmp(char_buffer_pointer, options[option_index])) {
@@ -279,6 +388,7 @@ void lingot_config_load(LingotConfig* config, char* filename) {
 			fprintf(stderr,
 					"warning: parse error at line %i: unknown keyword %s\n",
 					line, char_buffer_pointer);
+			parse_errors = 1;
 			continue;
 		}
 
@@ -293,6 +403,7 @@ void lingot_config_load(LingotConfig* config, char* filename) {
 		if (!char_buffer_pointer) {
 			fprintf(stderr,
 					"warning: parse error at line %i: value expected\n", line);
+			parse_errors = 1;
 			continue;
 		}
 
@@ -300,24 +411,33 @@ void lingot_config_load(LingotConfig* config, char* filename) {
 		switch (option_formats[option_index]) {
 		case 's':
 			sprintf(((char*) param), "%s", char_buffer_pointer);
+			command_count++;
 			break;
 		case 'd':
 			sscanf(char_buffer_pointer, "%d", (unsigned int*) param);
+			command_count++;
 			break;
 		case 'f':
 			sscanf(char_buffer_pointer, "%f", &aux);
 			*((FLT*) param) = aux;
+			command_count++;
 			break;
 		case 'm':
 			if (!strcmp("AUDIO_SYSTEM", option)) {
+				command_count++;
 				*((audio_system_t*) param) = str_to_audio_system_t(
 						char_buffer_pointer);
 				if (*((audio_system_t*) param) == (audio_system_t) -1) {
 					*((audio_system_t*) param) = AUDIO_SYSTEM_ALSA;
-					fprintf(
-							stderr,
-							"warning: parse error at line %i: unrecognized audio system '%s', assuming default audio system.\n",
+					char buff[1000];
+					sprintf(
+							buff,
+							_(
+									"Error parsing the configuration file, line %i: unrecognized audio system '%s', assuming default audio system.\n"),
 							line, char_buffer_pointer);
+
+					lingot_msg_add_warning(buff);
+					parse_errors = 1;
 				}
 			}
 			break;
@@ -326,6 +446,12 @@ void lingot_config_load(LingotConfig* config, char* filename) {
 
 	fclose(fp);
 
+	if (parse_errors) {
+		lingot_msg_add_warning(
+				_(
+						"The configuration file contains errors, and hence some default values have been chosen. Consider checking the settings and fixing the problem using the configuration dialog."));
+	}
+
 	lingot_config_update_internal_params(config);
 
 #   undef MAX_LINE_SIZE
