@@ -1,8 +1,7 @@
-//-*- C++ -*-
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2010  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
  *
  * This file is part of lingot.
  *
@@ -25,30 +24,30 @@
 #define __LINGOT_CONFIG_H__
 
 #include "lingot-defs.h"
-
-/*
- Configuration class. Determines the tuner's behaviour.
- Some parameters are internal only.
- */
+#include "lingot-config-scale.h"
 
 typedef enum audio_system_t {
 	AUDIO_SYSTEM_OSS = 0, AUDIO_SYSTEM_ALSA = 1, AUDIO_SYSTEM_JACK = 2
 } audio_system_t;
 
+typedef enum window_type_t {
+	NONE = 0, RECTANGULAR = 1, HANNING = 2, HAMMING = 3
+} window_type_t;
+
+
 typedef struct _LingotConfig LingotConfig;
 
+// Configuration struct. Determines the tuner behaviour.
+// Some parameters are internal only.
 struct _LingotConfig {
 
 	audio_system_t audio_system;
 
-	char audio_dev[80]; // default "/dev/dsp"
-	char audio_dev_alsa[80]; // default "plughw:0,0"
-	unsigned int sample_rate; // soundcard sample rate.
+	char audio_dev[3][80];
+	int sample_rate; // soundcard sample rate.
 	unsigned int oversampling; // oversampling factor.
 
-	// frequency of the root A note (internal parameter).
-	FLT root_frequency;
-
+	//	root_frequency_reference_note_t root_frequency_referente_note;
 	FLT root_frequency_error; // deviation of the above root frequency.
 
 	FLT min_frequency; // minimum valid frequency.
@@ -63,12 +62,11 @@ struct _LingotConfig {
 	// samples stored in the temporal window (internal parameter).
 	unsigned int temporal_buffer_size;
 
-	// samples read from soundcard (internal parameter).
-	unsigned int read_buffer_size;
-
 	FLT noise_threshold_db; // dB
 	FLT noise_threshold_nu; // natural units (internal parameter)
 
+	window_type_t window_type;
+
 	// frequency finding algorithm configuration
 	//-------------------------------------------
 
@@ -97,9 +95,11 @@ struct _LingotConfig {
 	//----------------------------------------------------------------------------
 
 	// gauge rest value. (gauge contemplates [-0.5, 0.5])
-	FLT vr;
+	FLT gauge_rest_value;
 
 	//----------------------------------------------------------------------------
+
+	LingotScale* scale;
 };
 
 // converts an audio_system_t to a string
@@ -109,12 +109,13 @@ audio_system_t str_to_audio_system_t(char* audio_system);
 
 LingotConfig* lingot_config_new();
 void lingot_config_destroy(LingotConfig*);
+void lingot_config_copy(LingotConfig* dst, LingotConfig* src);
 
 // back to default configuration.
-void lingot_config_reset(LingotConfig*);
+void lingot_config_restore_default_values(LingotConfig*);
 
 // derivate internal parameters from external ones.
-int lingot_config_update_internal_params(LingotConfig*);
+void lingot_config_update_internal_params(LingotConfig*);
 
 void lingot_config_save(LingotConfig*, char* filename);
 void lingot_config_load(LingotConfig*, char* filename);
