@@ -1,8 +1,7 @@
-//-*- C++ -*-
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2010  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
  *
  * This file is part of lingot.
  *
@@ -41,6 +40,10 @@ extern char CONFIG_FILE_NAME[];
 
 #define GTK_EVENTS_RATE      20.0
 #define GAUGE_RATE           60.0
+#define ERROR_DISPATCH_RATE	 5.0
+
+#define MID_A_FREQUENCY		440.0
+#define MID_C_FREQUENCY		261.625565
 
 /* object forward declaration */
 typedef struct _LingotMainFrame LingotMainFrame;
@@ -49,4 +52,16 @@ typedef struct _LingotMainFrame LingotMainFrame;
 //#define LIB_FFTW
 //#define LIBSNDOBJ
 
+// simple try-catch simulation, do not use throw inside loops nor nest try-catch
+// blocks
+#define try exception = 0; do
+#define throw(a) {exception = a;break;}
+#define catch while (0); if (exception != 0)
+
+// this option allows us to throw exception from loops, it contains a goto
+// statement, but totally controlled, and it fails to indent the code.
+//#define try exception = 0;do
+//#define throw(a) {exception = a;goto catch_label;}
+//#define catch while (0);catch_label: if (exception != 0)
+
 #endif
