@@ -1,8 +1,7 @@
-//-*- C++ -*-
 /*
  * lingot, a musical instrument tuner.
  *
- * Copyright (C) 2004-2010  Ibán Cereijo Graña, Jairo Chapela Martínez.
+ * Copyright (C) 2004-2011  Ibán Cereijo Graña, Jairo Chapela Martínez.
  *
  * This file is part of lingot.
  *
@@ -44,6 +43,6 @@ void lingot_signal_get_max(FLT *buffer, int N, int* Mi);
 int lingot_signal_get_fundamental_peak(LingotConfig*, FLT *x, FLT* y, int N);
 
 // generates a Hamming window of N samples
-void lingot_signal_hamming_window(int N, FLT* out);
+void lingot_signal_window(int N, FLT* out, window_type_t window_type);
 
 #endif /*__LINGOT_SIGNAL_H__*/
