@@ -40,6 +40,39 @@
 
 char CONFIG_FILE_NAME[100];
 
+//void print_card_list(void) {
+//   int status;
+//   int card = -1;  // use -1 to prime the pump of iterating through card list
+//   char* longname  = NULL;
+//   char* shortname = NULL;
+//
+//   if ((status = snd_card_next(&card)) < 0) {
+//      error("cannot determine card number: %s", snd_strerror(status));
+//      return;
+//   }
+//   if (card < 0) {
+//      error("no sound cards found");
+//      return;
+//   }
+//   while (card >= 0) {
+//      printf("Card %d:", card);
+//      if ((status = snd_card_get_name(card, &shortname)) < 0) {
+//         error("cannot determine card shortname: %s", snd_strerror(status));
+//         break;
+//      }
+//      if ((status = snd_card_get_longname(card, &longname)) < 0) {
+//         error("cannot determine card longname: %s", snd_strerror(status));
+//         break;
+//      }
+//      printf("\tLONG NAME:  %s\n", longname);
+//      printf("\tSHORT NAME: %s\n", shortname);
+//      if ((status = snd_card_next(&card)) < 0) {
+//         error("cannot determine card number: %s", snd_strerror(status));
+//         break;
+//      }
+//   }
+//}
+
 int main(int argc, char *argv[]) {
 
 #ifdef ENABLE_NLS
@@ -82,6 +115,7 @@ int main(int argc, char *argv[]) {
 
 			default:
 				printf("?? getopt returned character code 0%o ??\n", c);
+				break;
 			}
 		}
 	}
@@ -107,6 +141,8 @@ int main(int argc, char *argv[]) {
 	} else
 		fclose(fp);
 
+//	print_card_list();
+
 	lingot_gui_mainframe_create(argc, argv);
 
 	return 0;
